@@ -1,8 +1,9 @@
 from abc import abstractmethod
 from typing import Any, Type, Union, Optional, List, Tuple
+from onnx import ModelProto
 from falcon.abstract.model import Model
 from falcon.abstract.onnx_convertible import ONNXConvertible
-from falcon.serialization import SerializedModelRepr, serialize_to_falcon, serialize_to_onnx
+from falcon.serialization import SerializedModelRepr, serialize_to_onnx
 
 
 class PipelineElement(Model):
@@ -30,7 +31,7 @@ class PipelineElement(Model):
         """
         pass
 
-    def forward(self, X: Any) -> Any:
+    def forward(self, X: Any, *args: Any, **kwargs: Any) -> Any:
         """
         Equivalent of `predict` method that is used for elements chaining inside pipeline during inference.
 
@@ -44,9 +45,9 @@ class PipelineElement(Model):
         Any
             predictions
         """
-        self.predict(X)
+        return self.predict(X)
 
-    def fit_pipe(self, X: Any, y: Any) -> Any:
+    def fit_pipe(self, X: Any, y: Any, *args: Any, **kwargs: Any) -> Any:
         """
         Equivalent of `fit` method that is used for elements chaining inisde pipeline during training.
 
@@ -70,9 +71,13 @@ class Pipeline(Model):
     Base class for all pipelines.
     """
 
-    def __init__(self, task: str, **kwargs: Any) -> None:
+    def __init__(
+        self, task: str, dataset_size: Tuple[int, ...], mask: List[Any], **kwargs: Any
+    ) -> None:
         self.task = task
         self._pipeline: List[PipelineElement] = []
+        self.dataset_size = dataset_size
+        self.mask = mask
 
     def add_element(self, element: PipelineElement) -> None:
         """
@@ -94,40 +99,30 @@ class Pipeline(Model):
             raise ValueError("Cannot add self to the pipeline")
         self._pipeline.append(element)
 
-    def save(self, format: str = "auto") -> Tuple[bytes, str]:
+    def save(self, feature_names: Optional[List] = None) -> ModelProto:
         """
-        Serializes the model to string. For more details please refer to the documentation of `TaskManager.save_model(...)` method.
+        Exports the pipeline to ONNX ModelProto
 
         Parameters
         ----------
-        format : str, optional
-           `auto`, `falcon` or `onnx`, by default `auto`
-
+        feature_names : Optional[List], optional
+            feature names, by default None
         Returns
         -------
-        Tuple[SerializedModelRepr, str]
-            Serialized model, format
-
-
+        ModelProto
+            Pipeline as ONNX ModelProto
         """
-        if format not in {"falcon", "onnx"}:
-            raise ValueError(
-                f"expected one of [onnx, falcon] as output format, got {format}"
-            )
         serialized_pipeline_elements: List[SerializedModelRepr] = []
         for p in self._pipeline:
             if isinstance(p, ONNXConvertible):
                 serialized_pipeline_elements.append(p.to_onnx())
             else:
-                if format == "onnx":
-                    raise RuntimeError("This model cannot be serialized to onnx")
-                elif format == "auto":
-                    format = "falcon"
-        if format == "falcon":
-            serialized_model = serialize_to_falcon(serialized_pipeline_elements)
-        else:
-            format = "onnx"
-            serialized_model = serialize_to_onnx(
-                serialized_pipeline_elements
-            ).SerializeToString()
-        return serialized_model, format
+                raise RuntimeError("Encountered non convertible pipeline element")
+
+        serialized_model = serialize_to_onnx(
+            serialized_pipeline_elements,
+            task=self.task,
+            init_types=self.mask,
+            init_feature_names=feature_names,
+        )
+        return serialized_model
