@@ -1,6 +1,9 @@
 import numpy as np
 from numpy import typing as npt
-from falcon.types import Float32Array
+from falcon.types import Float32Array, ColumnTypes
+from sklearn.base import BaseEstimator
+from sklearn import __version__ as sklearn_version
+from packaging import version
 from sklearn.compose import ColumnTransformer
 from sklearn.preprocessing import StandardScaler
 from sklearn.preprocessing import OneHotEncoder
@@ -14,23 +17,66 @@ from sklearn.preprocessing import MaxAbsScaler, OrdinalEncoder
 from skl2onnx.sklapi import CastTransformer
 from falcon.serialization import SerializedModelRepr
 
+
 class ScalerAndEncoder(Processor, ONNXConvertible):
     """
     Applies OneHotEncoder/OrdinalEncoder on low/high cardinality categorical features and StandardScaler on numerical features.
     """
-    
-    def __init__(
-        self, mask: List[int]
-    ) -> None:  # [1/2 -> low/high cardinality categorical, 0 -> numerical]
+
+    def __init__(self, mask: List[ColumnTypes]) -> None:
         """
         Parameters
         ----------
-        mask : List[int]
-            boolean mask with True/False for categorical/numerical features
+        mask : List[ColumnTypes]
+            provides a type for each column at a given index
         """
         self.mask = mask
 
-    def fit(self, X: npt.NDArray, _: Any = None) -> None:
+    def _get_ohe(self) -> BaseEstimator:
+        if version.parse(sklearn_version) < version.parse("1.2.0"):
+            not_sparse = {"sparse": False}
+        else:
+            not_sparse = {"sparse_output": False}
+
+        method = SKLPipeline(
+            steps=[
+                ("cast_str", CastTransformer(dtype=np.str_)),
+                (
+                    "ohe",
+                    OneHotEncoder(
+                        categories="auto", handle_unknown="ignore", **not_sparse
+                    ),
+                ),
+            ]
+        )
+        return method
+
+    def _get_numeric_scaler(self) -> BaseEstimator:
+        return SKLPipeline(
+            steps=[
+                ("cast64", CastTransformer(dtype=np.float64)),
+                ("scaler", StandardScaler(with_mean=True, with_std=True)),
+                ("cast32", CastTransformer()),
+            ]
+        )
+
+    def _get_ordinal_encoder(self) -> BaseEstimator:
+        return SKLPipeline(
+            steps=[
+                ("cast_str", CastTransformer(dtype=np.str_)),
+                (
+                    "ord_enc",
+                    OrdinalEncoder(
+                        categories="auto",
+                        handle_unknown="use_encoded_value",
+                        unknown_value=-1,
+                    ),
+                ),
+                ("sc", MaxAbsScaler()),
+            ]
+        )
+
+    def fit(self, X: npt.NDArray, y: Any = None, *args: Any, **kwargs: Any) -> None:
         """
         Fits the encoder.
 
@@ -39,26 +85,24 @@ class ScalerAndEncoder(Processor, ONNXConvertible):
         X : npt.NDArray
             data to encode
         _ : Any, optional
-            dummy argument to keep compatibility with pipeline training, by default None
+            dummy argument to keep compatibility with pipeline training
         """
         transformers = []
+
         for i, v in enumerate(self.mask):
-            if v == 1:
-                method = OneHotEncoder(
-                    categories="auto", sparse=False, handle_unknown="ignore"
-                )
-            elif v == 0:
-                method = SKLPipeline(steps = [('cast64', CastTransformer(dtype=np.float64)),('scaler', StandardScaler(with_mean=True, with_std=True)),('cast32', CastTransformer())])
+            if v == ColumnTypes.CAT_LOW_CARD:
+                method = self._get_ohe()
+            elif v == ColumnTypes.NUMERIC_REGULAR:
+                method = self._get_numeric_scaler()
             else:
-                method = SKLPipeline(steps=[('ord_enc', OrdinalEncoder(categories="auto", handle_unknown = "use_encoded_value", unknown_value = -1)), ('sc', MaxAbsScaler())])
-            
+                method = self._get_ordinal_encoder()
             t = (f"input {i}", method, [i])
             transformers.append(t)
 
         self.ct = ColumnTransformer(transformers)
         self.ct.fit(X)
 
-    def predict(self, X: npt.NDArray) -> npt.NDArray:
+    def predict(self, X: npt.NDArray, *args: Any, **kwargs: Any) -> npt.NDArray:
         """
         Applies the encoder.
 
@@ -79,7 +123,7 @@ class ScalerAndEncoder(Processor, ONNXConvertible):
         Returns
         -------
         Type
-            npt.NDArray[np.object_]
+            object
         """
         return npt.NDArray[np.object_]
 
@@ -92,14 +136,16 @@ class ScalerAndEncoder(Processor, ONNXConvertible):
         """
         return Float32Array
 
-    def forward(self, X: npt.NDArray[np.object_]) -> npt.NDArray:
+    def forward(
+        self, X: npt.NDArray[np.object_], *args: Any, **kwargs: Any
+    ) -> npt.NDArray:
         """
         Equivalent of `.predict()` or `.transform()`.
 
 
         Parameters
         ----------
-        X : npt.NDArray[np.object_]
+        X : npt.NDArray[object]
             data to process
 
         Returns
@@ -111,7 +157,7 @@ class ScalerAndEncoder(Processor, ONNXConvertible):
 
     def to_onnx(self) -> SerializedModelRepr:
         """
-        Serializes the encoder to onnx. 
+        Serializes the encoder to onnx.
         Each feature in the original dataset is mapped to its own input node (`float32` for numerical or `string` for categorical).
 
         Returns
@@ -122,21 +168,24 @@ class ScalerAndEncoder(Processor, ONNXConvertible):
         initial_types_str: List[str] = []
         initial_shapes: List[List[Optional[int]]] = []
         for i, t in enumerate(self.mask):
-            if t == 1 or t == 2:
-                tensor = StringTensorType([None, 1])
-                initial_types_str.append("STRING")
-            else:
+            if t in [ColumnTypes.NUMERIC_REGULAR]:
                 tensor = FloatTensorType([None, 1])
                 initial_types_str.append("FLOAT32")
+            else:
+                tensor = StringTensorType([None, 1])
+                initial_types_str.append("STRING")
             initial_types.append((f"input{i}", tensor))
             initial_shapes.append([None, 1])
         return SerializedModelRepr(
             convert_sklearn(
                 self.ct,
                 initial_types=initial_types,
-                target_opset={'': ONNX_OPSET_VERSION, 'ai.onnx.ml': ML_ONNX_OPSET_VERSION},
+                target_opset={
+                    "": ONNX_OPSET_VERSION,
+                    "ai.onnx.ml": ML_ONNX_OPSET_VERSION,
+                },
                 options={StandardScaler: {"div": "div_cast"}},
-            ).SerializeToString(),
+            ),
             len(self.mask),
             1,
             initial_types_str,
